@@ -430,7 +430,11 @@ string CodeGenerator::getSyntaxDescription()
     return (currentSyntax)? currentSyntax->getDescription(): "syntax undef";
 
 }
+string CodeGenerator::getThemeDescription()
+{
+    return docStyle.getDescription();
 
+}
 unsigned int CodeGenerator::getLineNumber()
 {
     return lineNumber;
@@ -2232,7 +2236,7 @@ bool CodeGenerator::initPluginScript(const string& script)
             }
             listIdx++;
         }
-    }  catch (Diluculum::LuaError err) {
+    }  catch (Diluculum::LuaError &err) {
         userScriptError=err.what();
         return false;
     }
