@@ -89,6 +89,9 @@ private:
     QShortcut *copyShortcut;
     QShortcut *pasteShortcut;
     QFileSystemWatcher scriptWatcher;
+    QStringList themesClassic;
+    QStringList themesBase16;
+    int themesClassicIdx, themesBase16Idx;
 
     bool getDataFromCP;
 
@@ -115,6 +118,8 @@ private:
     string getFileSuffix(const string& fileName);
     string getFileBaseName(const string& fileName);
     void readLuaList(const string& paramName, const string& langName, Diluculum::LuaValue &luaVal, MMap* extMap);
+    void fillThemeCombo();
+    void showHelpFile(const QString& file);
 
     void dragEnterEvent(QDragEnterEvent *event);
     void dragMoveEvent(QDragMoveEvent *event);
@@ -158,6 +163,7 @@ private slots:
     void on_action_Manual_triggered();
     void on_action_About_Highlight_triggered();
     void on_action_Exit_triggered();
+
     void plausibility();
     void updatePreview();
     void openFiles();
@@ -168,6 +174,9 @@ private slots:
     void on_pbBrowseOutDir_clicked();
     void on_lvUserScripts_itemClicked(QListWidgetItem *item);
     void on_lvPluginScripts_itemClicked(QListWidgetItem *item);
+
+    void on_comboTheme_activated(int index);
+    void on_cbUseBase16_clicked();
 };
 
 #endif // MAINWINDOW_H
